@@ -5,6 +5,7 @@ import networkx as nx
 from metrics_layer.core.exceptions import (
     AccessDeniedOrDoesNotExistException,
     JoinError,
+    MetricsLayerException,
     QueryError,
 )
 
@@ -22,6 +23,7 @@ class Topic(MetricsLayerBase):
     valid_properties = [
         "version",
         "type",
+        "name",
         "label",
         "model_name",
         "base_view",
@@ -51,7 +53,11 @@ class Topic(MetricsLayerBase):
                 raise QueryError(f"Topic missing required key {k}{name_str}")
 
     def id(self):
-        return self.label
+        return self.name
+
+    @property
+    def name(self):
+        return self._definition.get("name", self.label)
 
     @property
     def model(self):
@@ -79,7 +85,15 @@ class Topic(MetricsLayerBase):
 
     def _error(self, element, error, extra: dict = {}):
         line, column = self.line_col(element)
-        return {**extra, "model_name": self.model_name, "message": error, "line": line, "column": column}
+        return {
+            **extra,
+            "model_name": self.model_name,
+            "message": error,
+            "line": line,
+            "column": column,
+            "reference_type": "topic",
+            "reference_id": self.label,
+        }
 
     def always_filter_literal(self):
         to_add = {"week_start_day": self.model.week_start_day, "timezone": self.project.timezone}
@@ -111,6 +125,13 @@ class Topic(MetricsLayerBase):
     def collect_errors(self):
         errors = []
 
+        if "name" in self._definition and not isinstance(self.name, str):
+            errors.append(
+                self._error(
+                    self.name, f"The name property, {self.name} must be a string in the topic {self.label}"
+                )
+            )
+
         if "label" in self._definition and not isinstance(self.label, str):
             errors.append(
                 self._error(
@@ -644,7 +665,9 @@ class Topic(MetricsLayerBase):
             join = self.project.join_graph.get_join(self.base_view, view_name)
             return join
         except KeyError:
-            raise ValueError(f"Join not found between {self.base_view} and {view_name}")
+            raise MetricsLayerException(
+                f"Join not found between {self.base_view} and {view_name} in the topic {self.label}"
+            )
 
     def join_graphs(self):
         join_graphs = []
