@@ -17,7 +17,10 @@ class MetricsLayerProjectReader(ProjectReaderBase):
 
         for fn in file_names:
             yaml_dict = self.read_yaml_file(fn)
-            yaml_dict["_file_path"] = os.path.relpath(fn, start=self.repo.folder)
+            if isinstance(yaml_dict, dict):
+                yaml_dict["_file_path"] = os.path.relpath(fn, start=self.repo.folder)
+            else:
+                continue
 
             # Handle keyerror
             if "type" not in yaml_dict and "zenlytic_project" not in fn:
