@@ -60,7 +60,15 @@ class SQLQueryResolver(SingleSQLQueryResolver):
 
     @property
     def is_merged_result(self):
-        has_explicit_merge = any(self.project.get_field(m).is_merged_result for m in self.metrics)
+        field_level_checks = []
+        for m in self.metrics:
+            referenced_field = self.project.get_field(m)
+            field_is_explicit_merge = referenced_field.is_merged_result
+            field_allows_explicit_merge = (
+                self.topic is None or referenced_field.canon_date != referenced_field.view.default_date
+            )
+            field_level_checks.append(field_is_explicit_merge and field_allows_explicit_merge)
+        has_explicit_merge = any(field_level_checks)
         has_specified_merge = self.kwargs.get("merged_result", False)
         return has_explicit_merge or has_specified_merge or self.mapping_forces_merged_result
 
@@ -591,7 +599,7 @@ class SQLQueryResolver(SingleSQLQueryResolver):
             for f in self.topic.always_filter:
                 if "." not in f["field"]:
                     raise QueryError(
-                        f"Always filter field {f['field']} in the topic {self.topic.label} must be a fully"
+                        f"Always filter field {f['field']} in the topic {self.topic.name} must be a fully"
                         " qualified field name in the format view_name.field_name"
                     )
                 always_where.extend(Filter({**f, **to_add}).filter_dict(json_safe=True))
